==> factorstochvol_1.0.2.tar.gz: factorstochvol/src/register.cpp <==
/*
 * R package stochvol by
 *     Gregor Kastner Copyright (C) 2016-2021
 *     Darjus Hosszejni Copyright (C) 2019-2021
 *     Luis Gruber Copyright (C) 2021
 *
 *  This file is part of the R package factorstochvol: Bayesian Estimation
 *  of (Sparse) Latent Factor Stochastic Volatility Models
 *
 *  The R package factorstochvol is free software: you can redistribute
 *  it and/or modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation, either version 2 or any
 *  later version of the License.
 *
 *  The R package factorstochvol is distributed in the hope that it will
 *  be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 *  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with the R package factorstochvol. If that is not the case,
 *  please refer to <http://www.gnu.org/licenses/>.
 */

#include "sampler.h"
#include "predict.h"
#include "dmvnorm.h"
#include "../inst/include/factorstochvol.h"

using namespace Rcpp;

static const R_CallMethodDef CallEntries[] = {
    {"sampler", (DL_FUNC) &sampler, 35},
    {"predict", (DL_FUNC) &predict, 3},
    {"dmvnorm", (DL_FUNC) &dmvnorm, 4},
    {NULL, NULL, 0}
};

RcppExport void R_init_factorstochvol(DllInfo *dll) {
    R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
    R_useDynamicSymbols(dll, FALSE);
    
    // register "sampler" to be available for other packages
    R_RegisterCCallable("factorstochvol", "sampler", (DL_FUNC)sampler);
}

==> factorstochvol_1.1.0.tar.gz: factorstochvol/src/register.cpp <==
/*
 * R package stochvol by
 *     Gregor Kastner Copyright (C) 2016-2021
 *     Darjus Hosszejni Copyright (C) 2019-2021
 *     Luis Gruber Copyright (C) 2021
 *
 *  This file is part of the R package factorstochvol: Bayesian Estimation
 *  of (Sparse) Latent Factor Stochastic Volatility Models
 *
 *  The R package factorstochvol is free software: you can redistribute
 *  it and/or modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation, either version 2 or any
 *  later version of the License.
 *
 *  The R package factorstochvol is distributed in the hope that it will
 *  be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 *  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with the R package factorstochvol. If that is not the case,
 *  please refer to <http://www.gnu.org/licenses/>.
 */

#include "sampler.h"
#include "predict.h"
#include "dmvnorm.h"
#include "update_fsv.h"
#include "../inst/include/factorstochvol.h"

using namespace Rcpp;

static const R_CallMethodDef CallEntries[] = {
    {"sampler", (DL_FUNC) &sampler, 35},
    {"predict", (DL_FUNC) &predict, 3},
    {"dmvnorm", (DL_FUNC) &dmvnorm, 4},
    {NULL, NULL, 0}
};

RcppExport void R_init_factorstochvol(DllInfo *dll) {
    R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
    R_useDynamicSymbols(dll, FALSE);
    
    // register "update_fsv" to be available for other packages
    R_RegisterCCallable("factorstochvol", "update_fsv", (DL_FUNC)update_fsv);
}
